# My App

## About this app

## Requirements


## How to run this app


![screenshot](img/screencapture.png)

## Resources

* [Dash](https://dash.plot.ly/)
* Inspired by [Tableau template](https://www.tableau.com/solutions/workbook/improve-patient-satisfaction-improving-cycle-time).
